NativeBridge class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
changeSetting(
String key, dynamic value) → Future< void> -
inputText(
String text) → Future< bool> -
isAccessibilityEnabled(
) → Future< bool> -
isDeviceOwner(
) → Future< bool> -
isScreenCaptureRunning(
) → Future< bool> -
lockDevice(
) → Future< void> -
openAccessibilitySettings(
) → Future< void> -
pressBack(
) → Future< bool> -
pressHome(
) → Future< bool> -
pressRecents(
) → Future< bool> -
releaseMediaProjection(
) → Future< bool> -
requestMediaProjection(
) → Future< bool> -
simulateSwipe(
double x1, double y1, double x2, double y2, {int duration = 300}) → Future< bool> -
simulateTouch(
double x, double y) → Future< bool> -
startScreenCapture(
) → Future< bool> -
stopScreenCapture(
) → Future< bool>