RemoteControl class
Constructors
Properties
- deviceMac → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactivityDuration → Duration
-
final
- isConnected → bool
-
no setter
-
onCustomCommand
→ Stream<
Map< String, dynamic> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverUrl → String
-
final
- token → String
-
final
- turnServerCredential → String?
-
final
- turnServerIP → String?
-
final
- turnServerPort → int?
-
final
- turnServerUsername → String?
-
final
Methods
-
connect(
) → Future< void> -
dispose(
) → Future< void> -
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reconnect(
) → Future< void> -
startScreenCapture(
) → Future< void> -
stopScreenCapture(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited